.. -*- mode: rst -*-

ImFil - Implicit Filtering
==========================

ImFil is intended for optimizing on derivative-free, noisy, blackbox functions.
This modified version has preset defaults as intended for hybrid quantum-classical
algorithms run on Noisy Intermediate Scale Quantum (NISQ) computers.

This version of ImFil was modified and redistributed with permission.

Copyright of original (v1.0.2):
   C.T. Kelley, NCSU

Copyright of modifications:
   UC Regents, Berkeley

Official website:
   https://ctk.math.ncsu.edu/imfil.html

Reference:
   C.T. Kelley, "Implicit Filtering", 2011, ISBN: 978-1-61197-189-7
   https://epubs.siam.org/doi/book/10.1137/1.9781611971903
